@@ -1,5 +1,3 @@
-package org.apache.maven.artifact.versioning;
-
 /*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
@@ -9,7 +7,7 @@ package org.apache.maven.artifact.versioning;
  * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
  *
- *  http://www.apache.org/licenses/LICENSE-2.0
+ *   http://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing,
  * software distributed under the License is distributed on an
@@ -18,14 +16,15 @@ package org.apache.maven.artifact.versioning;
  * specific language governing permissions and limitations
  * under the License.
  */
+package org.apache.maven.artifact.versioning;
 
 import java.util.ArrayList;
 import java.util.Collections;
 import java.util.Iterator;
 import java.util.List;
 import java.util.Map;
-import java.util.WeakHashMap;
 import java.util.Objects;
+import java.util.WeakHashMap;
 
 import org.apache.maven.artifact.Artifact;
 
@@ -34,55 +33,47 @@ import org.apache.maven.artifact.Artifact;
  *
  * @author <a href="mailto:brett@apache.org">Brett Porter</a>
  */
-public class VersionRange
-{
+public class VersionRange {
     private static final Map<String, VersionRange> CACHE_SPEC =
-        Collections.<String, VersionRange>synchronizedMap( new WeakHashMap<String, VersionRange>() );
+            Collections.<String, VersionRange>synchronizedMap(new WeakHashMap<String, VersionRange>());
 
     private static final Map<String, VersionRange> CACHE_VERSION =
-                    Collections.<String, VersionRange>synchronizedMap( new WeakHashMap<String, VersionRange>() );
+            Collections.<String, VersionRange>synchronizedMap(new WeakHashMap<String, VersionRange>());
 
     private final ArtifactVersion recommendedVersion;
 
     private final List<Restriction> restrictions;
 
-    private VersionRange( ArtifactVersion recommendedVersion,
-                          List<Restriction> restrictions )
-    {
+    private VersionRange(ArtifactVersion recommendedVersion, List<Restriction> restrictions) {
         this.recommendedVersion = recommendedVersion;
         this.restrictions = restrictions;
     }
 
-    public ArtifactVersion getRecommendedVersion()
-    {
+    public ArtifactVersion getRecommendedVersion() {
         return recommendedVersion;
     }
 
-    public List<Restriction> getRestrictions()
-    {
+    public List<Restriction> getRestrictions() {
         return restrictions;
     }
 
     /**
-     * @deprecated VersionRange is immutable, cloning is not useful and even more an issue against the cache 
+     * @deprecated VersionRange is immutable, cloning is not useful and even more an issue against the cache
      * @return a clone
      */
     @Deprecated
-    public VersionRange cloneOf()
-    {
+    public VersionRange cloneOf() {
         List<Restriction> copiedRestrictions = null;
 
-        if ( restrictions != null )
-        {
+        if (restrictions != null) {
             copiedRestrictions = new ArrayList<>();
 
-            if ( !restrictions.isEmpty() )
-            {
-                copiedRestrictions.addAll( restrictions );
+            if (!restrictions.isEmpty()) {
+                copiedRestrictions.addAll(restrictions);
             }
         }
 
-        return new VersionRange( recommendedVersion, copiedRestrictions );
+        return new VersionRange(recommendedVersion, copiedRestrictions);
     }
 
     /**
@@ -104,17 +95,13 @@ public class VersionRange
      * @throws InvalidVersionSpecificationException
      *
      */
-    public static VersionRange createFromVersionSpec( String spec )
-        throws InvalidVersionSpecificationException
-    {
-        if ( spec == null )
-        {
+    public static VersionRange createFromVersionSpec(String spec) throws InvalidVersionSpecificationException {
+        if (spec == null) {
             return null;
         }
 
-        VersionRange cached = CACHE_SPEC.get( spec );
-        if ( cached != null )
-        {
+        VersionRange cached = CACHE_SPEC.get(spec);
+        if (cached != null) {
             return cached;
         }
 
@@ -124,129 +111,106 @@ public class VersionRange
         ArtifactVersion upperBound = null;
         ArtifactVersion lowerBound = null;
 
-        while ( process.startsWith( "[" ) || process.startsWith( "(" ) )
-        {
-            int index1 = process.indexOf( ')' );
-            int index2 = process.indexOf( ']' );
+        while (process.startsWith("[") || process.startsWith("(")) {
+            int index1 = process.indexOf(')');
+            int index2 = process.indexOf(']');
 
             int index = index2;
-            if ( index2 < 0 || index1 < index2 )
-            {
-                if ( index1 >= 0 )
-                {
+            if (index2 < 0 || index1 < index2) {
+                if (index1 >= 0) {
                     index = index1;
                 }
             }
 
-            if ( index < 0 )
-            {
-                throw new InvalidVersionSpecificationException( "Unbounded range: " + spec );
+            if (index < 0) {
+                throw new InvalidVersionSpecificationException("Unbounded range: " + spec);
             }
 
-            Restriction restriction = parseRestriction( process.substring( 0, index + 1 ) );
-            if ( lowerBound == null )
-            {
+            Restriction restriction = parseRestriction(process.substring(0, index + 1));
+            if (lowerBound == null) {
                 lowerBound = restriction.getLowerBound();
             }
-            if ( upperBound != null )
-            {
-                if ( restriction.getLowerBound() == null || restriction.getLowerBound().compareTo( upperBound ) < 0 )
-                {
-                    throw new InvalidVersionSpecificationException( "Ranges overlap: " + spec );
+            if (upperBound != null) {
+                if (restriction.getLowerBound() == null
+                        || restriction.getLowerBound().compareTo(upperBound) < 0) {
+                    throw new InvalidVersionSpecificationException("Ranges overlap: " + spec);
                 }
             }
-            restrictions.add( restriction );
+            restrictions.add(restriction);
             upperBound = restriction.getUpperBound();
 
-            process = process.substring( index + 1 ).trim();
+            process = process.substring(index + 1).trim();
 
-            if ( process.length() > 0 && process.startsWith( "," ) )
-            {
-                process = process.substring( 1 ).trim();
+            if (process.length() > 0 && process.startsWith(",")) {
+                process = process.substring(1).trim();
             }
         }
 
-        if ( process.length() > 0 )
-        {
-            if ( restrictions.size() > 0 )
-            {
+        if (process.length() > 0) {
+            if (restrictions.size() > 0) {
                 throw new InvalidVersionSpecificationException(
-                    "Only fully-qualified sets allowed in multiple set scenario: " + spec );
-            }
-            else
-            {
-                version = new DefaultArtifactVersion( process );
-                restrictions.add( Restriction.EVERYTHING );
+                        "Only fully-qualified sets allowed in multiple set scenario: " + spec);
+            } else {
+                version = new DefaultArtifactVersion(process);
+                restrictions.add(Restriction.EVERYTHING);
             }
         }
 
-        cached = new VersionRange( version, restrictions );
-        CACHE_SPEC.put( spec, cached );
+        cached = new VersionRange(version, restrictions);
+        CACHE_SPEC.put(spec, cached);
         return cached;
     }
 
-    private static Restriction parseRestriction( String spec )
-        throws InvalidVersionSpecificationException
-    {
-        boolean lowerBoundInclusive = spec.startsWith( "[" );
-        boolean upperBoundInclusive = spec.endsWith( "]" );
+    private static Restriction parseRestriction(String spec) throws InvalidVersionSpecificationException {
+        boolean lowerBoundInclusive = spec.startsWith("[");
+        boolean upperBoundInclusive = spec.endsWith("]");
 
-        String process = spec.substring( 1, spec.length() - 1 ).trim();
+        String process = spec.substring(1, spec.length() - 1).trim();
 
         Restriction restriction;
 
-        int index = process.indexOf( ',' );
+        int index = process.indexOf(',');
 
-        if ( index < 0 )
-        {
-            if ( !lowerBoundInclusive || !upperBoundInclusive )
-            {
-                throw new InvalidVersionSpecificationException( "Single version must be surrounded by []: " + spec );
+        if (index < 0) {
+            if (!lowerBoundInclusive || !upperBoundInclusive) {
+                throw new InvalidVersionSpecificationException("Single version must be surrounded by []: " + spec);
             }
 
-            ArtifactVersion version = new DefaultArtifactVersion( process );
+            ArtifactVersion version = new DefaultArtifactVersion(process);
 
-            restriction = new Restriction( version, lowerBoundInclusive, version, upperBoundInclusive );
-        }
-        else
-        {
-            String lowerBound = process.substring( 0, index ).trim();
-            String upperBound = process.substring( index + 1 ).trim();
+            restriction = new Restriction(version, lowerBoundInclusive, version, upperBoundInclusive);
+        } else {
+            String lowerBound = process.substring(0, index).trim();
+            String upperBound = process.substring(index + 1).trim();
 
             ArtifactVersion lowerVersion = null;
-            if ( lowerBound.length() > 0 )
-            {
-                lowerVersion = new DefaultArtifactVersion( lowerBound );
+            if (lowerBound.length() > 0) {
+                lowerVersion = new DefaultArtifactVersion(lowerBound);
             }
             ArtifactVersion upperVersion = null;
-            if ( upperBound.length() > 0 )
-            {
-                upperVersion = new DefaultArtifactVersion( upperBound );
+            if (upperBound.length() > 0) {
+                upperVersion = new DefaultArtifactVersion(upperBound);
             }
 
-            if ( upperVersion != null && lowerVersion != null )
-            {
-                int result = upperVersion.compareTo( lowerVersion );
-                if ( result < 0 || ( result == 0 && ( !lowerBoundInclusive || !upperBoundInclusive ) ) )
-                {
-                    throw new InvalidVersionSpecificationException( "Range defies version ordering: " + spec );
+            if (upperVersion != null && lowerVersion != null) {
+                int result = upperVersion.compareTo(lowerVersion);
+                if (result < 0 || (result == 0 && (!lowerBoundInclusive || !upperBoundInclusive))) {
+                    throw new InvalidVersionSpecificationException("Range defies version ordering: " + spec);
                 }
             }
 
-            restriction = new Restriction( lowerVersion, lowerBoundInclusive, upperVersion, upperBoundInclusive );
+            restriction = new Restriction(lowerVersion, lowerBoundInclusive, upperVersion, upperBoundInclusive);
         }
 
         return restriction;
     }
 
-    public static VersionRange createFromVersion( String version )
-    {
-        VersionRange cached = CACHE_VERSION.get( version );
-        if ( cached == null )
-        {
+    public static VersionRange createFromVersion(String version) {
+        VersionRange cached = CACHE_VERSION.get(version);
+        if (cached == null) {
             List<Restriction> restrictions = Collections.emptyList();
-            cached = new VersionRange( new DefaultArtifactVersion( version ), restrictions );
-            CACHE_VERSION.put( version, cached );
+            cached = new VersionRange(new DefaultArtifactVersion(version), restrictions);
+            CACHE_VERSION.put(version, cached);
         }
         return cached;
     }
@@ -279,203 +243,148 @@ public class VersionRange
      * @throws NullPointerException if the specified <code>VersionRange</code> is
      *                              <code>null</code>.
      */
-    public VersionRange restrict( VersionRange restriction )
-    {
+    public VersionRange restrict(VersionRange restriction) {
         List<Restriction> r1 = this.restrictions;
         List<Restriction> r2 = restriction.restrictions;
         List<Restriction> restrictions;
 
-        if ( r1.isEmpty() || r2.isEmpty() )
-        {
+        if (r1.isEmpty() || r2.isEmpty()) {
             restrictions = Collections.emptyList();
-        }
-        else
-        {
-            restrictions = Collections.unmodifiableList( intersection( r1, r2 ) );
+        } else {
+            restrictions = Collections.unmodifiableList(intersection(r1, r2));
         }
 
         ArtifactVersion version = null;
-        if ( restrictions.size() > 0 )
-        {
-            for ( Restriction r : restrictions )
-            {
-                if ( recommendedVersion != null && r.containsVersion( recommendedVersion ) )
-                {
+        if (restrictions.size() > 0) {
+            for (Restriction r : restrictions) {
+                if (recommendedVersion != null && r.containsVersion(recommendedVersion)) {
                     // if we find the original, use that
                     version = recommendedVersion;
                     break;
-                }
-                else if ( version == null && restriction.getRecommendedVersion() != null
-                    && r.containsVersion( restriction.getRecommendedVersion() ) )
-                {
+                } else if (version == null
+                        && restriction.getRecommendedVersion() != null
+                        && r.containsVersion(restriction.getRecommendedVersion())) {
                     // use this if we can, but prefer the original if possible
                     version = restriction.getRecommendedVersion();
                 }
             }
         }
         // Either the original or the specified version ranges have no restrictions
-        else if ( recommendedVersion != null )
-        {
+        else if (recommendedVersion != null) {
             // Use the original recommended version since it exists
             version = recommendedVersion;
-        }
-        else if ( restriction.recommendedVersion != null )
-        {
+        } else if (restriction.recommendedVersion != null) {
             // Use the recommended version from the specified VersionRange since there is no
             // original recommended version
             version = restriction.recommendedVersion;
         }
-/* TODO should throw this immediately, but need artifact
-        else
-        {
-            throw new OverConstrainedVersionException( "Restricting incompatible version ranges" );
-        }
-*/
+        /* TODO should throw this immediately, but need artifact
+                else
+                {
+                    throw new OverConstrainedVersionException( "Restricting incompatible version ranges" );
+                }
+        */
 
-        return new VersionRange( version, restrictions );
+        return new VersionRange(version, restrictions);
     }
 
-    private List<Restriction> intersection( List<Restriction> r1, List<Restriction> r2 )
-    {
-        List<Restriction> restrictions = new ArrayList<>( r1.size() + r2.size() );
+    private List<Restriction> intersection(List<Restriction> r1, List<Restriction> r2) {
+        List<Restriction> restrictions = new ArrayList<>(r1.size() + r2.size());
         Iterator<Restriction> i1 = r1.iterator();
         Iterator<Restriction> i2 = r2.iterator();
         Restriction res1 = i1.next();
         Restriction res2 = i2.next();
 
         boolean done = false;
-        while ( !done )
-        {
-            if ( res1.getLowerBound() == null || res2.getUpperBound() == null
-                || res1.getLowerBound().compareTo( res2.getUpperBound() ) <= 0 )
-            {
-                if ( res1.getUpperBound() == null || res2.getLowerBound() == null
-                    || res1.getUpperBound().compareTo( res2.getLowerBound() ) >= 0 )
-                {
+        while (!done) {
+            if (res1.getLowerBound() == null
+                    || res2.getUpperBound() == null
+                    || res1.getLowerBound().compareTo(res2.getUpperBound()) <= 0) {
+                if (res1.getUpperBound() == null
+                        || res2.getLowerBound() == null
+                        || res1.getUpperBound().compareTo(res2.getLowerBound()) >= 0) {
                     ArtifactVersion lower;
                     ArtifactVersion upper;
                     boolean lowerInclusive;
                     boolean upperInclusive;
 
                     // overlaps
-                    if ( res1.getLowerBound() == null )
-                    {
+                    if (res1.getLowerBound() == null) {
                         lower = res2.getLowerBound();
                         lowerInclusive = res2.isLowerBoundInclusive();
-                    }
-                    else if ( res2.getLowerBound() == null )
-                    {
+                    } else if (res2.getLowerBound() == null) {
                         lower = res1.getLowerBound();
                         lowerInclusive = res1.isLowerBoundInclusive();
-                    }
-                    else
-                    {
-                        int comparison = res1.getLowerBound().compareTo( res2.getLowerBound() );
-                        if ( comparison < 0 )
-                        {
+                    } else {
+                        int comparison = res1.getLowerBound().compareTo(res2.getLowerBound());
+                        if (comparison < 0) {
                             lower = res2.getLowerBound();
                             lowerInclusive = res2.isLowerBoundInclusive();
-                        }
-                        else if ( comparison == 0 )
-                        {
+                        } else if (comparison == 0) {
                             lower = res1.getLowerBound();
                             lowerInclusive = res1.isLowerBoundInclusive() && res2.isLowerBoundInclusive();
-                        }
-                        else
-                        {
+                        } else {
                             lower = res1.getLowerBound();
                             lowerInclusive = res1.isLowerBoundInclusive();
                         }
                     }
 
-                    if ( res1.getUpperBound() == null )
-                    {
+                    if (res1.getUpperBound() == null) {
                         upper = res2.getUpperBound();
                         upperInclusive = res2.isUpperBoundInclusive();
-                    }
-                    else if ( res2.getUpperBound() == null )
-                    {
+                    } else if (res2.getUpperBound() == null) {
                         upper = res1.getUpperBound();
                         upperInclusive = res1.isUpperBoundInclusive();
-                    }
-                    else
-                    {
-                        int comparison = res1.getUpperBound().compareTo( res2.getUpperBound() );
-                        if ( comparison < 0 )
-                        {
+                    } else {
+                        int comparison = res1.getUpperBound().compareTo(res2.getUpperBound());
+                        if (comparison < 0) {
                             upper = res1.getUpperBound();
                             upperInclusive = res1.isUpperBoundInclusive();
-                        }
-                        else if ( comparison == 0 )
-                        {
+                        } else if (comparison == 0) {
                             upper = res1.getUpperBound();
                             upperInclusive = res1.isUpperBoundInclusive() && res2.isUpperBoundInclusive();
-                        }
-                        else
-                        {
+                        } else {
                             upper = res2.getUpperBound();
                             upperInclusive = res2.isUpperBoundInclusive();
                         }
                     }
 
                     // don't add if they are equal and one is not inclusive
-                    if ( lower == null || upper == null || lower.compareTo( upper ) != 0 )
-                    {
-                        restrictions.add( new Restriction( lower, lowerInclusive, upper, upperInclusive ) );
-                    }
-                    else if ( lowerInclusive && upperInclusive )
-                    {
-                        restrictions.add( new Restriction( lower, lowerInclusive, upper, upperInclusive ) );
+                    if (lower == null || upper == null || lower.compareTo(upper) != 0) {
+                        restrictions.add(new Restriction(lower, lowerInclusive, upper, upperInclusive));
+                    } else if (lowerInclusive && upperInclusive) {
+                        restrictions.add(new Restriction(lower, lowerInclusive, upper, upperInclusive));
                     }
 
                     //noinspection ObjectEquality
-                    if ( upper == res2.getUpperBound() )
-                    {
+                    if (upper == res2.getUpperBound()) {
                         // advance res2
-                        if ( i2.hasNext() )
-                        {
+                        if (i2.hasNext()) {
                             res2 = i2.next();
-                        }
-                        else
-                        {
+                        } else {
                             done = true;
                         }
-                    }
-                    else
-                    {
+                    } else {
                         // advance res1
-                        if ( i1.hasNext() )
-                        {
+                        if (i1.hasNext()) {
                             res1 = i1.next();
-                        }
-                        else
-                        {
+                        } else {
                             done = true;
                         }
                     }
-                }
-                else
-                {
+                } else {
                     // move on to next in r1
-                    if ( i1.hasNext() )
-                    {
+                    if (i1.hasNext()) {
                         res1 = i1.next();
-                    }
-                    else
-                    {
+                    } else {
                         done = true;
                     }
                 }
-            }
-            else
-            {
+            } else {
                 // move on to next in r2
-                if ( i2.hasNext() )
-                {
+                if (i2.hasNext()) {
                     res2 = i2.next();
-                }
-                else
-                {
+                } else {
                     done = true;
                 }
             }
@@ -484,19 +393,13 @@ public class VersionRange
         return restrictions;
     }
 
-    public ArtifactVersion getSelectedVersion( Artifact artifact )
-        throws OverConstrainedVersionException
-    {
+    public ArtifactVersion getSelectedVersion(Artifact artifact) throws OverConstrainedVersionException {
         ArtifactVersion version;
-        if ( recommendedVersion != null )
-        {
+        if (recommendedVersion != null) {
             version = recommendedVersion;
-        }
-        else
-        {
-            if ( restrictions.size() == 0 )
-            {
-                throw new OverConstrainedVersionException( "The artifact has no valid ranges", artifact );
+        } else {
+            if (restrictions.size() == 0) {
+                throw new OverConstrainedVersionException("The artifact has no valid ranges", artifact);
             }
 
             version = null;
@@ -504,60 +407,44 @@ public class VersionRange
         return version;
     }
 
-    public boolean isSelectedVersionKnown( Artifact artifact )
-        throws OverConstrainedVersionException
-    {
+    public boolean isSelectedVersionKnown(Artifact artifact) throws OverConstrainedVersionException {
         boolean value = false;
-        if ( recommendedVersion != null )
-        {
+        if (recommendedVersion != null) {
             value = true;
-        }
-        else
-        {
-            if ( restrictions.size() == 0 )
-            {
-                throw new OverConstrainedVersionException( "The artifact has no valid ranges", artifact );
+        } else {
+            if (restrictions.size() == 0) {
+                throw new OverConstrainedVersionException("The artifact has no valid ranges", artifact);
             }
         }
         return value;
     }
 
-    public String toString()
-    {
-        if ( recommendedVersion != null )
-        {
+    public String toString() {
+        if (recommendedVersion != null) {
             return recommendedVersion.toString();
-        }
-        else
-        {
+        } else {
             StringBuilder buf = new StringBuilder();
-            for ( Iterator<Restriction> i = restrictions.iterator(); i.hasNext(); )
-            {
+            for (Iterator<Restriction> i = restrictions.iterator(); i.hasNext(); ) {
                 Restriction r = i.next();
 
-                buf.append( r.toString() );
+                buf.append(r.toString());
 
-                if ( i.hasNext() )
-                {
-                    buf.append( ',' );
+                if (i.hasNext()) {
+                    buf.append(',');
                 }
             }
             return buf.toString();
         }
     }
 
-    public ArtifactVersion matchVersion( List<ArtifactVersion> versions )
-    {
+    public ArtifactVersion matchVersion(List<ArtifactVersion> versions) {
         // TODO could be more efficient by sorting the list and then moving along the restrictions in order?
 
         ArtifactVersion matched = null;
-        for ( ArtifactVersion version : versions )
-        {
-            if ( containsVersion( version ) )
-            {
+        for (ArtifactVersion version : versions) {
+            if (containsVersion(version)) {
                 // valid - check if it is greater than the currently matched version
-                if ( matched == null || version.compareTo( matched ) > 0 )
-                {
+                if (matched == null || version.compareTo(matched) > 0) {
                     matched = version;
                 }
             }
@@ -565,44 +452,36 @@ public class VersionRange
         return matched;
     }
 
-    public boolean containsVersion( ArtifactVersion version )
-    {
-        for ( Restriction restriction : restrictions )
-        {
-            if ( restriction.containsVersion( version ) )
-            {
+    public boolean containsVersion(ArtifactVersion version) {
+        for (Restriction restriction : restrictions) {
+            if (restriction.containsVersion(version)) {
                 return true;
             }
         }
         return false;
     }
 
-    public boolean hasRestrictions()
-    {
+    public boolean hasRestrictions() {
         return !restrictions.isEmpty() && recommendedVersion == null;
     }
 
-    public boolean equals( Object obj )
-    {
-        if ( this == obj )
-        {
+    public boolean equals(Object obj) {
+        if (this == obj) {
             return true;
         }
-        if ( !( obj instanceof VersionRange ) )
-        {
+        if (!(obj instanceof VersionRange)) {
             return false;
         }
         VersionRange other = (VersionRange) obj;
 
-        return Objects.equals( recommendedVersion, other.recommendedVersion )
-            && Objects.equals( restrictions, other.restrictions );
+        return Objects.equals(recommendedVersion, other.recommendedVersion)
+                && Objects.equals(restrictions, other.restrictions);
     }
 
-    public int hashCode()
-    {
+    public int hashCode() {
         int hash = 7;
-        hash = 31 * hash + ( recommendedVersion == null ? 0 : recommendedVersion.hashCode() );
-        hash = 31 * hash + ( restrictions == null ? 0 : restrictions.hashCode() );
+        hash = 31 * hash + (recommendedVersion == null ? 0 : recommendedVersion.hashCode());
+        hash = 31 * hash + (restrictions == null ? 0 : restrictions.hashCode());
         return hash;
     }
 }
