@@ -1,5 +1,3 @@
-package org.apache.maven.usability.plugin;
-
 /*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
@@ -9,7 +7,7 @@ package org.apache.maven.usability.plugin;
  * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
  *
- *  http://www.apache.org/licenses/LICENSE-2.0
+ *   http://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing,
  * software distributed under the License is distributed on an
@@ -18,23 +16,19 @@ package org.apache.maven.usability.plugin;
  * specific language governing permissions and limitations
  * under the License.
  */
+package org.apache.maven.usability.plugin;
 
 /**
  * ExpressionDocumentationException
  */
-public class ExpressionDocumentationException
-    extends Exception
-{
+public class ExpressionDocumentationException extends Exception {
     static final long serialVersionUID = 1;
 
-    public ExpressionDocumentationException( String message, Throwable cause )
-    {
-        super( message, cause );
+    public ExpressionDocumentationException(String message, Throwable cause) {
+        super(message, cause);
     }
 
-    public ExpressionDocumentationException( String message )
-    {
-        super( message );
+    public ExpressionDocumentationException(String message) {
+        super(message);
     }
-
 }
