@@ -1,5 +1,3 @@
-package org.apache.maven.profiles.manager;
-
 /*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
@@ -9,7 +7,7 @@ package org.apache.maven.profiles.manager;
  * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
  *
- *  http://www.apache.org/licenses/LICENSE-2.0
+ *   http://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing,
  * software distributed under the License is distributed on an
@@ -18,6 +16,7 @@ package org.apache.maven.profiles.manager;
  * specific language governing permissions and limitations
  * under the License.
  */
+package org.apache.maven.profiles.manager;
 
 import java.util.List;
 import java.util.Properties;
@@ -31,178 +30,164 @@ import org.codehaus.plexus.ContainerConfiguration;
 import org.codehaus.plexus.PlexusConstants;
 import org.codehaus.plexus.PlexusTestCase;
 
-public class DefaultProfileManagerTest
-    extends PlexusTestCase
-{
+public class DefaultProfileManagerTest extends PlexusTestCase {
 
     @Override
-    protected void customizeContainerConfiguration( ContainerConfiguration configuration )
-    {
-        super.customizeContainerConfiguration( configuration );
-        configuration.setAutoWiring( true );
-        configuration.setClassPathScanning( PlexusConstants.SCANNING_ON );
+    protected void customizeContainerConfiguration(ContainerConfiguration configuration) {
+        super.customizeContainerConfiguration(configuration);
+        configuration.setAutoWiring(true);
+        configuration.setClassPathScanning(PlexusConstants.SCANNING_ON);
     }
 
-    public void testShouldActivateDefaultProfile()
-        throws Exception
-    {
+    public void testShouldActivateDefaultProfile() throws Exception {
         Profile notActivated = new Profile();
-        notActivated.setId( "notActivated" );
+        notActivated.setId("notActivated");
 
         Activation nonActivation = new Activation();
 
-        nonActivation.setJdk( "19.2" );
+        nonActivation.setJdk("19.2");
 
-        notActivated.setActivation( nonActivation );
+        notActivated.setActivation(nonActivation);
 
         Profile defaultActivated = new Profile();
-        defaultActivated.setId( "defaultActivated" );
+        defaultActivated.setId("defaultActivated");
 
         Activation defaultActivation = new Activation();
 
-        defaultActivation.setActiveByDefault( true );
+        defaultActivation.setActiveByDefault(true);
 
-        defaultActivated.setActivation( defaultActivation );
+        defaultActivated.setActivation(defaultActivation);
 
         Properties props = System.getProperties();
 
-        ProfileManager profileManager = new DefaultProfileManager( getContainer(), props );
+        ProfileManager profileManager = new DefaultProfileManager(getContainer(), props);
 
-        profileManager.addProfile( notActivated );
-        profileManager.addProfile( defaultActivated );
+        profileManager.addProfile(notActivated);
+        profileManager.addProfile(defaultActivated);
 
         List active = profileManager.getActiveProfiles();
 
-        assertNotNull( active );
-        assertEquals( 1, active.size() );
-        assertEquals( "defaultActivated", ( (Profile) active.get( 0 ) ).getId() );
+        assertNotNull(active);
+        assertEquals(1, active.size());
+        assertEquals("defaultActivated", ((Profile) active.get(0)).getId());
     }
 
-    public void testShouldNotActivateDefaultProfile()
-        throws Exception
-    {
+    public void testShouldNotActivateDefaultProfile() throws Exception {
         Profile syspropActivated = new Profile();
-        syspropActivated.setId( "syspropActivated" );
+        syspropActivated.setId("syspropActivated");
 
         Activation syspropActivation = new Activation();
 
         ActivationProperty syspropProperty = new ActivationProperty();
-        syspropProperty.setName( "java.version" );
+        syspropProperty.setName("java.version");
 
-        syspropActivation.setProperty( syspropProperty );
+        syspropActivation.setProperty(syspropProperty);
 
-        syspropActivated.setActivation( syspropActivation );
+        syspropActivated.setActivation(syspropActivation);
 
         Profile defaultActivated = new Profile();
-        defaultActivated.setId( "defaultActivated" );
+        defaultActivated.setId("defaultActivated");
 
         Activation defaultActivation = new Activation();
 
-        defaultActivation.setActiveByDefault( true );
+        defaultActivation.setActiveByDefault(true);
 
-        defaultActivated.setActivation( defaultActivation );
+        defaultActivated.setActivation(defaultActivation);
 
         Properties props = System.getProperties();
 
-        ProfileManager profileManager = new DefaultProfileManager( getContainer(), props );
+        ProfileManager profileManager = new DefaultProfileManager(getContainer(), props);
 
-        profileManager.addProfile( syspropActivated );
-        profileManager.addProfile( defaultActivated );
+        profileManager.addProfile(syspropActivated);
+        profileManager.addProfile(defaultActivated);
 
         List active = profileManager.getActiveProfiles();
 
-        assertNotNull( active );
-        assertEquals( 1, active.size() );
-        assertEquals( "syspropActivated", ( (Profile) active.get( 0 ) ).getId() );
+        assertNotNull(active);
+        assertEquals(1, active.size());
+        assertEquals("syspropActivated", ((Profile) active.get(0)).getId());
     }
 
-
-    public void testShouldNotActivateReversalOfPresentSystemProperty()
-        throws Exception
-    {
+    public void testShouldNotActivateReversalOfPresentSystemProperty() throws Exception {
         Profile syspropActivated = new Profile();
-        syspropActivated.setId( "syspropActivated" );
+        syspropActivated.setId("syspropActivated");
 
         Activation syspropActivation = new Activation();
 
         ActivationProperty syspropProperty = new ActivationProperty();
-        syspropProperty.setName( "!java.version" );
+        syspropProperty.setName("!java.version");
 
-        syspropActivation.setProperty( syspropProperty );
+        syspropActivation.setProperty(syspropProperty);
 
-        syspropActivated.setActivation( syspropActivation );
+        syspropActivated.setActivation(syspropActivation);
 
         Properties props = System.getProperties();
 
-        ProfileManager profileManager = new DefaultProfileManager( getContainer(), props );
+        ProfileManager profileManager = new DefaultProfileManager(getContainer(), props);
 
-        profileManager.addProfile( syspropActivated );
+        profileManager.addProfile(syspropActivated);
 
         List active = profileManager.getActiveProfiles();
 
-        assertNotNull( active );
-        assertEquals( 0, active.size() );
+        assertNotNull(active);
+        assertEquals(0, active.size());
     }
 
-    public void testShouldOverrideAndActivateInactiveProfile()
-        throws Exception
-    {
+    public void testShouldOverrideAndActivateInactiveProfile() throws Exception {
         Profile syspropActivated = new Profile();
-        syspropActivated.setId( "syspropActivated" );
+        syspropActivated.setId("syspropActivated");
 
         Activation syspropActivation = new Activation();
 
         ActivationProperty syspropProperty = new ActivationProperty();
-        syspropProperty.setName( "!java.version" );
+        syspropProperty.setName("!java.version");
 
-        syspropActivation.setProperty( syspropProperty );
+        syspropActivation.setProperty(syspropProperty);
 
-        syspropActivated.setActivation( syspropActivation );
+        syspropActivated.setActivation(syspropActivation);
 
         Properties props = System.getProperties();
 
-        ProfileManager profileManager = new DefaultProfileManager( getContainer(), props );
+        ProfileManager profileManager = new DefaultProfileManager(getContainer(), props);
 
-        profileManager.addProfile( syspropActivated );
+        profileManager.addProfile(syspropActivated);
 
-        profileManager.explicitlyActivate( "syspropActivated" );
+        profileManager.explicitlyActivate("syspropActivated");
 
         List active = profileManager.getActiveProfiles();
 
-        assertNotNull( active );
-        assertEquals( 1, active.size() );
-        assertEquals( "syspropActivated", ( (Profile) active.get( 0 ) ).getId() );
+        assertNotNull(active);
+        assertEquals(1, active.size());
+        assertEquals("syspropActivated", ((Profile) active.get(0)).getId());
     }
 
-    public void testShouldOverrideAndDeactivateActiveProfile()
-        throws Exception
-    {
+    public void testShouldOverrideAndDeactivateActiveProfile() throws Exception {
         Profile syspropActivated = new Profile();
-        syspropActivated.setId( "syspropActivated" );
+        syspropActivated.setId("syspropActivated");
 
         Activation syspropActivation = new Activation();
 
         ActivationProperty syspropProperty = new ActivationProperty();
-        syspropProperty.setName( "java.version" );
+        syspropProperty.setName("java.version");
 
-        syspropActivation.setProperty( syspropProperty );
+        syspropActivation.setProperty(syspropProperty);
 
-        syspropActivated.setActivation( syspropActivation );
+        syspropActivated.setActivation(syspropActivation);
 
         Properties props = System.getProperties();
 
-        ProfileManager profileManager = new DefaultProfileManager( getContainer(), props );
+        ProfileManager profileManager = new DefaultProfileManager(getContainer(), props);
 
-        profileManager.addProfile( syspropActivated );
+        profileManager.addProfile(syspropActivated);
 
-        profileManager.explicitlyDeactivate( "syspropActivated" );
+        profileManager.explicitlyDeactivate("syspropActivated");
 
         List active = profileManager.getActiveProfiles();
 
-        assertNotNull( active );
-        assertEquals( 0, active.size() );
+        assertNotNull(active);
+        assertEquals(0, active.size());
     }
-/*
+    /*
     public void testOsActivationProfile()
         throws Exception
     {
