@@ -1,5 +1,3 @@
-package org.apache.maven.artifact.repository.metadata;
-
 /*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
@@ -9,7 +7,7 @@ package org.apache.maven.artifact.repository.metadata;
  * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
  *
- *  http://www.apache.org/licenses/LICENSE-2.0
+ *   http://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing,
  * software distributed under the License is distributed on an
@@ -18,23 +16,19 @@ package org.apache.maven.artifact.repository.metadata;
  * specific language governing permissions and limitations
  * under the License.
  */
+package org.apache.maven.artifact.repository.metadata;
 
 /**
  * Error while deploying repository metadata.
  *
  * @author <a href="mailto:brett@apache.org">Brett Porter</a>
  */
-public class RepositoryMetadataDeploymentException
-    extends Throwable
-{
-    public RepositoryMetadataDeploymentException( String message )
-    {
-        super( message );
+public class RepositoryMetadataDeploymentException extends Throwable {
+    public RepositoryMetadataDeploymentException(String message) {
+        super(message);
     }
 
-    public RepositoryMetadataDeploymentException( String message,
-                                                  Exception e )
-    {
-        super( message, e );
+    public RepositoryMetadataDeploymentException(String message, Exception e) {
+        super(message, e);
     }
 }
