@@ -1,5 +1,3 @@
-package org.apache.maven.cli.transfer;
-
 /*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
@@ -9,7 +7,7 @@ package org.apache.maven.cli.transfer;
  * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
  *
- *  http://www.apache.org/licenses/LICENSE-2.0
+ *   http://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing,
  * software distributed under the License is distributed on an
@@ -18,14 +16,11 @@ package org.apache.maven.cli.transfer;
  * specific language governing permissions and limitations
  * under the License.
  */
+package org.apache.maven.cli.transfer;
 
 import org.eclipse.aether.transfer.AbstractTransferListener;
 
 /**
  * @author Benjamin Bentmann
  */
-public class QuietMavenTransferListener
-    extends AbstractTransferListener
-{
-
-}
+public class QuietMavenTransferListener extends AbstractTransferListener {}
