@@ -1,5 +1,3 @@
-package org.apache.maven.model.building;
-
 /*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
@@ -18,20 +16,17 @@ package org.apache.maven.model.building;
  * specific language governing permissions and limitations
  * under the License.
  */
+package org.apache.maven.model.building;
 
 /**
  * Provides a skeleton implementation for model building listeners. The methods of this class are empty.
  *
  * @author Benjamin Bentmann
  */
-public class AbstractModelBuildingListener
-    implements ModelBuildingListener
-{
+public class AbstractModelBuildingListener implements ModelBuildingListener {
 
     @Override
-    public void buildExtensionsAssembled( ModelBuildingEvent event )
-    {
+    public void buildExtensionsAssembled(ModelBuildingEvent event) {
         // default does nothing
     }
-
 }
